@@ -47,8 +47,8 @@ INLINE_PRESERVE_PATTERN = r"^===(.+)=== *$"
 COMPILED_INLINE_PRESERVE_REGEX = re.compile(INLINE_PRESERVE_PATTERN)
 
 # Output instruction markers
-OUTPUT_INSTRUCTION_PREFIX = "[输出]"
-OUTPUT_INSTRUCTION_SUFFIX = "[/输出]"
+OUTPUT_INSTRUCTION_PREFIX = "<preserve_or_translate>"
+OUTPUT_INSTRUCTION_SUFFIX = "</preserve_or_translate>"
 
 # System message templates
 DEFAULT_VALIDATION_SYSTEM_MESSAGE = "你是一个输入验证助手，需要严格按照指定的格式和规则处理用户输入。"
@@ -90,19 +90,44 @@ VALIDATION_RESPONSE_OK = "ok"
 VALIDATION_RESPONSE_ILLEGAL = "illegal"
 
 # Output instruction processing
-OUTPUT_INSTRUCTION_EXPLANATION = f"""请按照以下指令执行：
+OUTPUT_INSTRUCTION_EXPLANATION = f"""<preserve_or_translate_instruction>
+对{OUTPUT_INSTRUCTION_PREFIX}{OUTPUT_INSTRUCTION_SUFFIX}标记之间的内容的处理规则:
 
-当遇到{OUTPUT_INSTRUCTION_PREFIX}content{OUTPUT_INSTRUCTION_SUFFIX}这样的标签对时：
-1. **完全原样输出**中间的content内容，不要进行任何格式转换或修改
-2. 不要输出{OUTPUT_INSTRUCTION_PREFIX}和{OUTPUT_INSTRUCTION_SUFFIX}标签本身
-3. 即使content内容包含标题符号（如#）、特殊格式等，也要原样输出，不要转换成Markdown格式
-4. 保持content中的所有原始字符、空格、换行符等
-5. 然后继续执行后面的指令
+<default_behavior>
+默认行为: 完全保持原样输出
+- 标记之间的内容必须逐字原样输出
+- 严禁改写、润色、优化或调整任何表达方式
+- 严禁添加、删除或替换任何文字
+</default_behavior>
 
-重要提醒：
-- {OUTPUT_INSTRUCTION_PREFIX}和{OUTPUT_INSTRUCTION_SUFFIX}只是指令标记，不要将这些标记作为内容输出
-- 标签内的内容必须原样输出，不要按照文档提示词的格式要求进行转换
-- 这是绝对的输出指令，优先级高于任何格式要求
+<exception_rule>
+唯一例外: 语言翻译
+- 仅当内容需要从一种语言翻译成另一种语言时，才可以翻译
+- 翻译时必须保持原文的完整含义、语气和格式
+- 如果内容无需翻译，则绝对不允许做任何改动
+</exception_rule>
+
+<output_requirement>
+输出要求:
+- 不要输出{OUTPUT_INSTRUCTION_PREFIX}{OUTPUT_INSTRUCTION_SUFFIX}标记本身
+- 只输出标记之间的实际内容
+</output_requirement>
+
+<examples>
+示例1 - 保持原样:
+  <original_content>{OUTPUT_INSTRUCTION_PREFIX}**下面我们做个练习。**{OUTPUT_INSTRUCTION_SUFFIX}</original_content>
+  <resolved_content>**下面我们做个练习。**</resolved_content>
+
+示例2 - 语言翻译:
+  <original_content>{OUTPUT_INSTRUCTION_PREFIX}**Let's do an exercise.**{OUTPUT_INSTRUCTION_SUFFIX}</original_content>
+  <resolved_content>**让我们做个练习。**</resolved_content>
+
+示例3 - 错误示范(同语言改写):
+  <original_content>{OUTPUT_INSTRUCTION_PREFIX}**下面我们做个练习。**{OUTPUT_INSTRUCTION_SUFFIX}</original_content>
+  <wrong_output>**来，咱们做个有趣的小练习**</wrong_output>
+  <reason>错误: 擅自改写了中文内容</reason>
+</examples>
+</preserve_or_translate_instruction>
 
 """
 
