@@ -5,7 +5,7 @@ Provides LLM provider interfaces and related data models, supporting multiple pr
 """
 
 from abc import ABC, abstractmethod
-from collections.abc import Generator
+from collections.abc import AsyncGenerator
 from dataclasses import dataclass
 from enum import Enum
 from typing import Any
@@ -29,7 +29,6 @@ class LLMResult:
     prompt: str | None = None  # Used prompt
     variables: dict[str, str | list[str]] | None = None  # Extracted variables
     metadata: dict[str, Any] | None = None  # Metadata
-    transformed_to_interaction: bool = False  # Whether content block was transformed to interaction block
 
     def __bool__(self):
         """Support boolean evaluation."""
@@ -40,23 +39,22 @@ class LLMProvider(ABC):
     """Abstract LLM provider interface."""
 
     @abstractmethod
-    def complete(self, messages: list[dict[str, str]], tools: list[dict[str, Any]] | None = None) -> LLMResult:
+    async def complete(self, messages: list[dict[str, str]]) -> str:
         """
-        Non-streaming LLM call with optional function calling support.
+        Non-streaming LLM call.
 
         Args:
             messages: Message list in format [{"role": "system/user/assistant", "content": "..."}]
-            tools: Optional tools/functions for LLM to call
 
         Returns:
-            LLMResult: Structured result with content and metadata
+            str: LLM response content
 
         Raises:
             ValueError: When LLM call fails
         """
 
     @abstractmethod
-    def stream(self, messages: list[dict[str, str]]) -> Generator[str, None, None]:
+    async def stream(self, messages: list[dict[str, str]]) -> AsyncGenerator[str, None]:
         """
         Streaming LLM call.
 
@@ -74,8 +72,8 @@ class LLMProvider(ABC):
 class NoLLMProvider(LLMProvider):
     """Empty LLM provider for prompt-only scenarios."""
 
-    def complete(self, messages: list[dict[str, str]], tools: list[dict[str, Any]] | None = None) -> LLMResult:
+    async def complete(self, messages: list[dict[str, str]]) -> str:
         raise NotImplementedError(NO_LLM_PROVIDER_ERROR)
 
-    def stream(self, messages: list[dict[str, str]]) -> Generator[str, None, None]:
+    async def stream(self, messages: list[dict[str, str]]) -> AsyncGenerator[str, None]:
         raise NotImplementedError(NO_LLM_PROVIDER_ERROR)
